﻿
' -----------------------------------------------------------------------------------------
'
' RadarTurmSechs                                                     Ulrich Müller 01.02.10
'                                                                    Aspire VB 2008 Express
' Drehkranz mit Motor M1, Endtaster I1, Impulstaster C1 und roter Lampe O5
' Turm mit Motor M2, Endtaster I2, Impulstaster C2 und Ultraschallsensor I8
' scannt die Umgebung auf Gegenstände und macht Positions- und Entfernungsangaben
' bei Unterschreitung DistLimit wird die rote Lampe an O5 eingeschaltet
'              Basis Robo TX Controller und FishFaceTX.DLL
'
' -----------------------------------------------------------------------------------------

Option Explicit On
Option Strict Off
Imports FishFaceTX
Module SechsMain

  Dim tx As New FishFace()
  Const motTurm As Mot = Mot.M1
  Const endTurm As Unv = Unv.I1
  Const impTurm As Cnt = Cnt.C1
  Const motSensor As Mot = Mot.M2
  Const endSensor As Unv = Unv.I2
  Const impSensor As Cnt = Cnt.C2
  Const roteLampe As Out = Out.O5
  Const ultraSensor As Unv = Unv.I8

  Const SchrittWeite = 5
  Const SchrittAufAb = 3
  Const DistLimit = 16

  Sub Main()
    ' --- Verbindung zum TX Controller, COM-Namen nach Ansage RoboTxTest korrigieren
    tx.OpenController("COM4")
    Console.WriteLine("gestartet")

    ' --- Turm auf Grundstellung ---
    tx.SetMotor(motTurm, Dir.Left)
    tx.WaitForInput(endTurm)
    tx.SetMotor(motTurm, Dir.Off)

    ' --- EndlosSchleife Turm ---
    Do Until tx.Finish()
      ' --- Turm rechts ---
      For i As Int32 = 0 To 21 Step SchrittWeite
        If tx.Finish() Then Exit For
        Distance(Dir.Right, i)
      Next
      ' --- Turm links ---
      For i As Int16 = 20 - SchrittWeite To SchrittWeite - 1 Step -SchrittWeite
        If tx.Finish() Then Exit For
        Distance(Dir.Left, i)
      Next
    Loop
    ' --- Ende ----
    tx.CloseController()
    Console.WriteLine("FINIS")
    Console.ReadLine()
  End Sub

  Sub Distance(ByVal Turn As Dir, ByVal Pos As Int32)
    ' --- Schleife über Sensor Neigen ---
    Dim Distanz As Int32

    ' --- Sensor auf Grundstellung Oben ---
    tx.SetMotor(motSensor, Dir.Left)
    tx.WaitForInput(endSensor)
    tx.SetMotor(motSensor, Dir.Right)

    ' --- Sensor abwärts ---
    For i As Int16 = 0 To 7
      If tx.Finish() Then Return
      ' --- Feststellen Entfernung, ggf. rote Lampe
      Distanz = tx.GetDistance(Unv.I8)
      If Distanz < DistLimit Then
        tx.SetLamp(roteLampe, Dir.On)
      Else
        tx.SetLamp(roteLampe, Dir.Off)
      End If
      ' --- Anzeige Position, einen Schritt weiter ---
      Console.WriteLine("Position : {0:000} / {2:000}  Radarwert : {1:0000}", _
                        Pos, Distanz, i)
      tx.WaitForCount(impSensor, SchrittAufAb)
    Next

    tx.SetMotor(motSensor, Dir.Off)
    ' --- Turm ein Schritt weiter ---
    tx.StartRobMotor(motTurm, Turn, 512, SchrittWeite)
    tx.WaitForMotor(motTurm)
  End Sub
End Module
